@@ -293,55 +293,44 @@ void save_sync_anchors( OSyncMember *member, const irmc_config *config )
   osync_trace(TRACE_ENTRY, "%s(%p, %p)", __func__, member, config);			
   char anchor[ 1024 ];
 
-  snprintf( anchor, sizeof( anchor ), "%d:%s", config->calendar_changecounter, config->calendar_dbid );
-  osync_anchor_update( member, "event", anchor );
-
-  snprintf( anchor, sizeof( anchor ), "%d:%s", config->addressbook_changecounter, config->addressbook_dbid );
-  osync_anchor_update( member, "contact", anchor );
-
-  snprintf( anchor, sizeof( anchor ), "%d:%s", config->notebook_changecounter, config->notebook_dbid );
-  osync_anchor_update( member, "note", anchor );
+  if (osync_member_objtype_enabled(member, "event")) {
+	if (config->calendar_changecounter >= 0 && strcmp(config->calendar_dbid, "FFFFFF")) {
+		snprintf( anchor, sizeof( anchor ), "%d:%s", config->calendar_changecounter, config->calendar_dbid );
+  		osync_anchor_update( member, "event", anchor );
+	} else {
+  		osync_trace(TRACE_INTERNAL, "ERROR: Invalid values for event anchor detected.");
+	}
+  } else {
+  	osync_trace(TRACE_INTERNAL, "WARNING: Synchronization of events was disabled.");
+  }
+ 
+  if (osync_member_objtype_enabled(member, "contact")) {
+	if (config->addressbook_changecounter >= 0 && strcmp(config->addressbook_dbid, "FFFFFF")) {
+		snprintf( anchor, sizeof( anchor ), "%d:%s", config->addressbook_changecounter, config->addressbook_dbid );
+  		osync_anchor_update( member, "contact", anchor );
+	} else {
+  		osync_trace(TRACE_INTERNAL, "ERROR: Invalid values for contact anchor detected.");
+	}
+  } else {
+  	osync_trace(TRACE_INTERNAL, "WARNING: Synchronization of contacts was disabled.");
+  }
 
+  if (osync_member_objtype_enabled(member, "note")) {
+	if (config->notebook_changecounter >= 0 && strcmp(config->notebook_dbid, "FFFFFF")) {
+		snprintf( anchor, sizeof( anchor ), "%d:%s", config->notebook_changecounter, config->notebook_dbid );
+  		osync_anchor_update( member, "note", anchor );
+	} else {
+  		osync_trace(TRACE_INTERNAL, "ERROR: Invalid values for note anchor detected.");
+	}
+  } else {
+  	osync_trace(TRACE_INTERNAL, "WARNING: Synchronization of notes was disabled.");
+  }
+   
   snprintf( anchor, sizeof( anchor ), "%s", config->serial_number );
   osync_anchor_update( member, "general", anchor );
   osync_trace(TRACE_EXIT, "%s", __func__);
 }
 
-#if HAVE_BLUETOOTH
-/**
- * Scan for available bluetooth devices and return a list of
- * found devices in xml structure.
- */
-void *scan_devices( void *foo, const char *query, void *bar )
-{
-  osync_trace(TRACE_ENTRY, "%s(%p, %s, %p)", __func__, foo, query, bar);			
-  xmlDoc *doc;
-  xmlNode *node, *devices;
-  xmlChar *data;
-  int size;
-
-  doc = xmlNewDoc((const xmlChar*)"1.0");
-  devices = xmlNewDocNode(doc, NULL, (const xmlChar*)"devices", NULL);
-  xmlDocSetRootElement(doc, devices);
-
-  GList *unit_list = find_bt_units();
-  for (; unit_list; unit_list = unit_list->next) {
-    irmc_bt_unit *unit = unit_list->data;
-    node = xmlNewTextChild(devices, NULL, (const xmlChar*)"device", NULL);
-    xmlNewProp(node, (const xmlChar*)"address", (const xmlChar*)(unit->address));
-    char *number = g_strdup_printf("%d", unit->channel);
-    xmlNewProp(node, (const xmlChar*)"channel", (const xmlChar*)number);
-    g_free(number);
-    xmlNewProp(node, (const xmlChar*)"name", (const xmlChar*)(unit->name));
-  }
-
-  xmlDocDumpFormatMemory( doc, &data, &size, 0 );
-
-  osync_trace(TRACE_EXIT, "%s: %p", __func__, data);
-  return data;
-}
-#endif
-
 /**
  * Tests whether a connection to a device with the given configuration can
  * be established.
@@ -421,17 +410,15 @@ gboolean detect_slowsync(int changecounter, char *object, char **dbid, char **se
   char serial[256];
   char did[256] = "";
   char *filename;
-  //int foo;
   int ret;
 
   data = g_malloc(DATABUFSIZE);
   datap = data;
 
-  len = DATABUFSIZE;
   filename = g_strdup_printf("telecom/%s/luid/%d.log", object, changecounter);
 
   memset(data, 0, DATABUFSIZE);
-  len = DATABUFSIZE;
+  len = DATABUFSIZE - 1;
   if (!irmc_obex_get(obexhandle, filename, data, &len, error)) {
     g_free(filename);
     g_free(data);
@@ -630,8 +617,10 @@ static void irmcGetChangeinfo(OSyncContext *ctx)
   strcpy(info.path_extension, "vcs");
   info.change_counter = &(config->calendar_changecounter);
 
-  if (osync_member_objtype_enabled(env->member, "event") && !get_generic_changeinfo(ctx, &info, &error))
-    goto error;
+  if (osync_member_objtype_enabled(env->member, "event")) {
+    if (!get_generic_changeinfo(ctx, &info, &error))
+      goto error;
+  }
 
   memset(&info, 0, sizeof(info));
   strcpy(info.name, "addressbook");
@@ -640,8 +629,10 @@ static void irmcGetChangeinfo(OSyncContext *ctx)
   strcpy(info.path_extension, "vcf");
   info.change_counter = &(config->addressbook_changecounter);
 
-  if (osync_member_objtype_enabled(env->member, "contact") && !get_generic_changeinfo(ctx, &info, &error))
-    goto error;
+  if (osync_member_objtype_enabled(env->member, "contact")) {
+    if (!get_generic_changeinfo(ctx, &info, &error))
+      goto error;
+  }
 
   memset(&info, 0, sizeof(info));
   strcpy(info.name, "notebook");
@@ -650,8 +641,10 @@ static void irmcGetChangeinfo(OSyncContext *ctx)
   strcpy(info.path_extension, "vnt");
   info.change_counter = &(config->notebook_changecounter);
 
-  if (osync_member_objtype_enabled(env->member, "note") && !get_generic_changeinfo(ctx, &info, &error))
-    goto error;
+  if (osync_member_objtype_enabled(env->member, "note")) {
+    if (!get_generic_changeinfo(ctx, &info, &error))
+      goto error;
+  }
 
   osync_context_report_success(ctx);
   osync_trace(TRACE_EXIT, "%s", __func__);
@@ -763,7 +756,7 @@ gboolean get_generic_changeinfo(OSyncContext *ctx, data_type_information *info,
     else if ( strcmp( info->identifier, "contact" ) == 0 )
       create_addressbook_changeinfo( SLOW_SYNC, ctx, buffer, 0, 0 );
     else if ( strcmp( info->identifier, "note" ) == 0 )
-      create_notebook_changeinfo( SLOW_SYNC, ctx, buffer, 0, 0 );
+     create_notebook_changeinfo( SLOW_SYNC, ctx, buffer, 0, 0 );
 
   } else {
     osync_trace(TRACE_INTERNAL, "fastsync %s\n", info->name );
@@ -933,7 +926,7 @@ void create_calendar_changeinfo(int sync_type, OSyncContext *ctx, char *data, ch
         if (objtype == SYNC_OBJECT_TYPE_CALENDAR)
           osync_change_set_objformat_string(change, "vevent10");
         else if (objtype == SYNC_OBJECT_TYPE_TODO)
-          osync_change_set_objformat_string(change, "vtodo20");
+          osync_change_set_objformat_string(change, "vtodo10");
 
         event_start = strstr(event, "X-IRMC-LUID:");
         if (event_start) {
@@ -967,7 +960,8 @@ void create_calendar_changeinfo(int sync_type, OSyncContext *ctx, char *data, ch
       event_size = 0;
     }
 
-    if (type == 'H')
+    /* H stands for hard delete. D stands for delete. */
+    if (type == 'H' || type == 'D')
       osync_change_set_changetype(change, CHANGE_DELETED);
     else if (type == 'M' || event_size == 0) {
       osync_change_set_data(change, data, event_size, TRUE);
@@ -1042,7 +1036,8 @@ void create_addressbook_changeinfo(int sync_type, OSyncContext *ctx, char *data,
       vcard_size = 0;
     }
 
-    if (type == 'H')
+    /* H stands for hard delete. D stands for delete. */
+    if (type == 'H' || type == 'D')
       osync_change_set_changetype(change, CHANGE_DELETED);
     else if (type == 'M' || vcard_size == 0) {
       osync_change_set_changetype(change, CHANGE_MODIFIED);
@@ -1119,7 +1114,8 @@ void create_notebook_changeinfo(int sync_type, OSyncContext *ctx, char *data, ch
       vnote_size = 0;
     }
 
-    if (type == 'H')
+    /* H stands for hard delete. D stands for delete. */
+    if (type == 'H' || type == 'D')
       osync_change_set_changetype(change, CHANGE_DELETED);
     else if (type == 'M' || vnote_size == 0) {
       osync_change_set_changetype(change, CHANGE_MODIFIED);
@@ -1413,8 +1409,8 @@ void get_info(OSyncEnv *env)
   osync_plugin_set_commit_objformat(info, "event", "vevent10", irmcCalendarCommitChange);
 
   osync_plugin_accept_objtype(info, "todo");
-  osync_plugin_accept_objformat(info, "todo", "vtodo20", NULL);
-  osync_plugin_set_commit_objformat(info, "todo", "vtodo20", irmcCalendarCommitChange);
+  osync_plugin_accept_objformat(info, "todo", "vtodo10", NULL);
+  osync_plugin_set_commit_objformat(info, "todo", "vtodo10", irmcCalendarCommitChange);
 
   osync_plugin_accept_objtype(info, "note");
   osync_plugin_accept_objformat(info, "note", "vnote11", NULL);
